from datetime import datetime
import enum

from sqlalchemy import create_engine
from sqlalchemy.orm import declarative_base, Mapped, mapped_column, sessionmaker
from sqlalchemy import Enum, JSON


SQLALCHEMY_DATABASE_URL = "sqlite:///./bebe.db"


engine = create_engine(
    SQLALCHEMY_DATABASE_URL, connect_args={"check_same_thread": False}
)


SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)


Base = declarative_base()


def create_all():
    Base.metadata.create_all(engine)


def drop_all():
    Base.metadata.drop_all(engine)


class EventTypes(enum.Enum):
    kakanje = "kakanje"
    hranenje = "hranenje"
    presoblakanje = "presoblakanje"
    tezina = "tezina"


class Event(Base):
    __tablename__ = "event"
    __table_args__ = {
        "sqlite_autoincrement": True,
    }

    id: Mapped[int] = mapped_column(autoincrement=True, primary_key=True)
    updated_at: Mapped[datetime] = mapped_column(default=datetime.now(), nullable=False)

    event_type = mapped_column(Enum(EventTypes), nullable=False)
    start_time: Mapped[datetime] = mapped_column(default=datetime.now(), nullable=False)
    end_time: Mapped[datetime] = mapped_column(nullable=True)
    data = mapped_column(JSON, nullable=True)


if __name__ == "__main__":
    drop_all()
    create_all()
